@@ -99,13 +99,12 @@ def opt(arg, help=None, type=None, abbrev=None, choices=None, metavar=None):
         _annotate, arg, (help, 'option', abbrev, type, choices, metavar))
 
 
-def flg(arg, help=None, type=None, abbrev=None, choices=None, metavar=None):
+def flg(arg, help=None, abbrev=None):
     """
     Decorator for annotating flags
     """
-    abbrev = abbrev or arg[0]
     return functools.partial(
-        _annotate, arg, (help, 'flag', abbrev, type, choices, metavar))
+        _annotate, arg, (help, 'flag', abbrev or arg[0], None, None, None))
 
 
 def is_annotation(obj):
@@ -271,7 +270,8 @@ class ArgumentParser(argparse.ArgumentParser):
         if collision:
             self.error(
                 _('colliding keyword arguments: %s') % ' '.join(collision))
-        args = [getattr(ns, a) for a in self.argspec.args]
+        # Correct options with trailing undescores
+        args = [getattr(ns, a.rstrip('_')) for a in self.argspec.args]
         varargs = getattr(ns, self.argspec.varargs or '', [])
         return cmd, self.func(*(args + varargs + extraopts), **kwargs)
 
@@ -350,11 +350,19 @@ class ArgumentParser(argparse.ArgumentParser):
                 if not metavar and default == '':
                     metavar = "''"
             if a.kind in ('option', 'flag'):
+
+                if name.endswith("_"):
+                    # allows reserved words to be specified with underscores
+                    suffix = name.rstrip('_')
+                else:
+                    # convert undescores to dashes.
+                    suffix = name.replace('_', '-')
+
                 if a.abbrev:
                     shortlong = (prefix + a.abbrev,
-                                 prefix*2 + name.replace('_', '-'))
+                                 prefix*2 + suffix)
                 else:
-                    shortlong = (prefix + name.replace('_', '-'),)
+                    shortlong = (prefix + suffix,)
             elif default is NONE:  # required argument
                 self.add_argument(name, help=a.help, type=a.type,
                                   choices=a.choices, metavar=metavar)
